#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import packages
from zope.interface import Interface
from zope.schema import Bool, Set, Choice

# import interfaces
from pyams_content.component.paragraph.interfaces import PARAGRAPH_FACTORIES_VOCABULARY
from pyams_default_theme import _


class IAssociationParagraphRemoteContentRendererSettings(Interface):
    """Associations paragraph remote content renderer settings interface"""

    display_title = Bool(title=_("Display title?"),
                         description=_("Choose 'yes' to display remote content's title"),
                         required=True,
                         default=False)

    display_header = Bool(title=_("Display header?"),
                          description=_("Choose 'yes' to display remote content's header"),
                          required=True,
                          default=False)

    factories = Set(title=_("Paragraph types"),
                    description=_("Select list of paragraph types you want to include; an empty "
                                  "selection means that all paragraphs will be selected"),
                    required=False,
                    value_type=Choice(vocabulary=PARAGRAPH_FACTORIES_VOCABULARY))

    anchors_only = Bool(title=_("Anchors only?"),
                        description=_("If 'yes', only paragraphs set as 'anchors' will be selected"),
                        required=True,
                        default=True)
